@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+
 from django.contrib import admin
 
 from axes.models import AccessLog
@@ -53,7 +55,7 @@ class AccessAttemptAdmin(admin.ModelAdmin):
         'failures_since_start'
     ]
 
-    def has_add_permission(self, request, obj=None):
+    def has_add_permission(self, request):
         return False
 
 admin.site.register(AccessAttempt, AccessAttemptAdmin)
@@ -104,7 +106,7 @@ class AccessLogAdmin(admin.ModelAdmin):
         'logout_time'
     ]
 
-    def has_add_permission(self, request, obj=None):
+    def has_add_permission(self, request):
         return False
 
 admin.site.register(AccessLog, AccessLogAdmin)
