@@ -1,21 +1,21 @@
+from __future__ import unicode_literals
+
 from datetime import timedelta
 from hashlib import md5
 
 from django.contrib.auth import get_user_model
 from django.utils import timezone
 
-from ipware.ip import get_ip
-
 from axes.conf import settings
 from axes.models import AccessAttempt
-from axes.utils import get_axes_cache
+from axes.utils import get_axes_cache, get_client_ip
 
 
 def _query_user_attempts(request):
     """Returns access attempt record if it exists.
     Otherwise return None.
     """
-    ip = get_ip(request)
+    ip = get_client_ip(request)
     username = request.POST.get(settings.AXES_USERNAME_FORM_FIELD, None)
 
     if settings.AXES_ONLY_USER_FAILURES:
@@ -41,7 +41,7 @@ def _query_user_attempts(request):
         else:
             params['ip_address'] = ip
 
-        if settings.AXES_USE_USER_AGENT:
+        if settings.AXES_USE_USER_AGENT and not settings.AXES_ONLY_USER_FAILURES:
             params['user_agent'] = ua
 
         attempts = AccessAttempt.objects.filter(**params)
@@ -60,7 +60,7 @@ def get_cache_key(request_or_obj):
         un = request_or_obj.username
         ua = request_or_obj.user_agent
     else:
-        ip = get_ip(request_or_obj)
+        ip = get_client_ip(request_or_obj)
         un = request_or_obj.POST.get(settings.AXES_USERNAME_FORM_FIELD, None)
         ua = request_or_obj.META.get('HTTP_USER_AGENT', '<unknown>')[:255]
 
@@ -75,7 +75,7 @@ def get_cache_key(request_or_obj):
     else:
         attributes = ip
 
-    if settings.AXES_USE_USER_AGENT:
+    if settings.AXES_USE_USER_AGENT and not settings.AXES_ONLY_USER_FAILURES:
         attributes += ua
 
     cache_hash_key = 'axes-{}'.format(md5(attributes).hexdigest())
@@ -88,7 +88,7 @@ def get_cache_timeout():
     cache_timeout = None
     cool_off = settings.AXES_COOLOFF_TIME
     if cool_off:
-        if (isinstance(cool_off, int) or isinstance(cool_off, float)):
+        if isinstance(cool_off, (int, float)):
             cache_timeout = timedelta(hours=cool_off).total_seconds()
         else:
             cache_timeout = cool_off.total_seconds()
@@ -104,7 +104,7 @@ def get_user_attempts(request):
 
     cool_off = settings.AXES_COOLOFF_TIME
     if cool_off:
-        if (isinstance(cool_off, int) or isinstance(cool_off, float)):
+        if isinstance(cool_off, (int, float)):
             cool_off = timedelta(hours=cool_off)
 
         for attempt in attempts:
@@ -176,7 +176,7 @@ def is_user_lockable(request):
 
 
 def is_already_locked(request):
-    ip = get_ip(request)
+    ip = get_client_ip(request)
 
     if (
         settings.AXES_ONLY_USER_FAILURES or
