@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+
 from datetime import timedelta
 from functools import wraps
 import json
@@ -10,13 +12,12 @@ from django.shortcuts import render
 from axes import get_version
 from axes.conf import settings
 from axes.attempts import is_already_locked
-from axes.utils import iso8601
-
+from axes.utils import iso8601, get_lockout_message
 
 log = logging.getLogger(settings.AXES_LOGGER)
 if settings.AXES_VERBOSE:
     log.info('AXES: BEGIN LOG')
-    log.info('AXES: Using django-axes ' + get_version())
+    log.info('AXES: Using django-axes %s', get_version())
     if settings.AXES_ONLY_USER_FAILURES:
         log.info('AXES: blocking by username only.')
     elif settings.AXES_LOCK_OUT_BY_COMBINATION_USER_AND_IP:
@@ -54,7 +55,7 @@ def lockout_response(request):
 
     cool_off = settings.AXES_COOLOFF_TIME
     if cool_off:
-        if (isinstance(cool_off, int) or isinstance(cool_off, float)):
+        if isinstance(cool_off, (int, float)):
             cool_off = timedelta(hours=cool_off)
 
         context.update({
@@ -76,11 +77,4 @@ def lockout_response(request):
     elif settings.AXES_LOCKOUT_URL:
         return HttpResponseRedirect(settings.AXES_LOCKOUT_URL)
 
-    else:
-        msg = 'Account locked: too many login attempts. {0}'
-        if settings.AXES_COOLOFF_TIME:
-            msg = msg.format('Please try again later.')
-        else:
-            msg = msg.format('Contact an admin to unlock your account.')
-
-        return HttpResponse(msg, status=403)
+    return HttpResponse(get_lockout_message(), status=403)
